"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addPackageAncestorNodeModulesToNodeRequirePath = void 0;
const path_1 = require("path");
const module_1 = require("module");
const debug_logger_1 = require("./debug-logger");
const fs_1 = require("fs");
function addPackageAncestorNodeModulesToNodeRequirePath() {
    const ancestorNodeModules = findAncestorNodeModules(__dirname, []);
    (0, debug_logger_1.debugLog)('Ancestor Node Modules Found: ', ancestorNodeModules);
    ancestorNodeModules.forEach(addToNodePath);
    // Re-initialize the paths into require
    module_1.Module._initPaths();
}
exports.addPackageAncestorNodeModulesToNodeRequirePath = addPackageAncestorNodeModulesToNodeRequirePath;
function addToNodePath(dir) {
    (0, debug_logger_1.debugLog)('Adding dir to NODE_PATH for resolution: ', dir);
    // NODE_PATH is a delimited list of paths.
    // The delimiter is different for windows.
    const delimiter = require('path').delimiter;
    const paths = process.env.NODE_PATH
        ? process.env.NODE_PATH.split(delimiter)
        : [];
    // The path is already in the node path
    if (paths.includes(dir)) {
        return;
    }
    // Add the tmp path
    paths.push(dir);
    // Update the env variable.
    process.env.NODE_PATH = paths.join(delimiter);
}
function findAncestorNodeModules(startPath, collector) {
    let currentPath = (0, path_1.isAbsolute)(startPath) ? startPath : (0, path_1.resolve)(startPath);
    while (currentPath !== (0, path_1.dirname)(currentPath)) {
        const potentialNodeModules = (0, path_1.join)(currentPath, 'node_modules');
        if ((0, fs_1.existsSync)(potentialNodeModules)) {
            collector.push(potentialNodeModules);
        }
        if ((0, fs_1.existsSync)((0, path_1.join)(currentPath, 'nx.json')) || collector.length == 1) {
            break;
        }
        currentPath = (0, path_1.dirname)(currentPath);
    }
    return collector;
}
//# sourceMappingURL=resolution-helpers.js.map